==> arquillian-parent-1.1.12.Final-source-release.zip: arquillian-parent-1.1.12.Final/junit/core/src/test/java/org/jboss/arquillian/junit/ArquillianClass1WithTimeout.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.junit;

import static org.jboss.arquillian.junit.JUnitTestBaseClass.wasCalled;

import org.jboss.arquillian.junit.JUnitTestBaseClass.Cycle;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.junit.runner.RunWith;

/*
 * Predfined TestClass
 */
@RunWith(Arquillian.class)
public class ArquillianClass1WithTimeout
{
   @BeforeClass
   public static void beforeClass() throws Throwable
   {
      wasCalled(Cycle.BEFORE_CLASS);
   }

   @AfterClass
   public static void afterClass() throws Throwable
   {
      wasCalled(Cycle.AFTER_CLASS);
   }

   @Before
   public void before() throws Throwable
   {
      wasCalled(Cycle.BEFORE);
   }

   @After
   public void after() throws Throwable
   {
      wasCalled(Cycle.AFTER);
   }

   @Test(timeout = 500)
   public void shouldBeInvoked() throws Throwable
   {
      wasCalled(Cycle.TEST);
      Thread.sleep(1001);
   }
}

==> arquillian-parent-1.1.15.Final-source-release.zip: arquillian-parent-1.1.15.Final/junit/core/src/test/java/org/jboss/arquillian/junit/ArquillianClass1WithTimeout.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.junit;

import org.jboss.arquillian.junit.JUnitTestBaseClass.Cycle;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.junit.runner.RunWith;

import static org.jboss.arquillian.junit.JUnitTestBaseClass.wasCalled;

/*
 * Predfined TestClass
 */
@RunWith(Arquillian.class)
public class ArquillianClass1WithTimeout {
    @BeforeClass
    public static void beforeClass() throws Throwable {
        wasCalled(Cycle.BEFORE_CLASS);
    }

    @AfterClass
    public static void afterClass() throws Throwable {
        wasCalled(Cycle.AFTER_CLASS);
    }

    @Before
    public void before() throws Throwable {
        wasCalled(Cycle.BEFORE);
    }

    @After
    public void after() throws Throwable {
        wasCalled(Cycle.AFTER);
    }

    @Test(timeout = 500)
    public void shouldBeInvoked() throws Throwable {
        wasCalled(Cycle.TEST);
        Thread.sleep(1001);
    }
}
